cx_Freeze Example
=================

First, install the packages: ``tdl``, ``libtcod-cffi``, and ``cx_Freeze``.

Then run the command::

    python setup.py build_exe

An executable package will be built at ``build/<platform>/``

The cx_Freeze documentation can be found at: https://cx-freeze.readthedocs.io
